DefaultMarkPlatform class
The default interface implementation acting as a placeholder for the native implementation to be set.
This implementation is not used by any of the implementations in this repository, and exists only for backward compatibility with any clients that were relying on internal details of the method channel in the pre-federated plugin.
- Inheritance
-
- Object
- PlatformInterface
- MarkPlatform
- DefaultMarkPlatform
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
authenticate(
{required MarkAuthenticatorType authenticatorType, required String title, String? subTitle, required String description, required String negativeText, bool confirmationRequired = false, required dynamic onSuccessAuthenticate(), dynamic onFailedAuthenticate()?, required dynamic onErrorAuthenticate(String code, String? message), dynamic onNegativeButtonClicked(int which)?, dynamic onCanceled()?}) → Future< void> -
override
-
authenticateSecureDecrypt(
{required String alias, required String encodedKey, required Map< String, String> requestForDecrypt, required String title, String? subTitle, required String description, required String negativeText, bool confirmationRequired = false, required dynamic onSuccessAuthenticate(SuccessAuthenticateDecryptState state), dynamic onFailedAuthenticate()?, required dynamic onErrorAuthenticate(String code, String? message), dynamic onNegativeButtonClicked(int which)?, dynamic onCanceled()?}) → Future<void> -
override
-
authenticateSecureEncrypt(
{required String alias, required Map< String, String> requestForEncrypt, required String title, String? subTitle, required String description, required String negativeText, bool confirmationRequired = false, required dynamic onSuccessAuthenticate(SuccessAuthenticateEncryptState state), dynamic onFailedAuthenticate()?, required dynamic onErrorAuthenticate(String code, String? message), dynamic onNegativeButtonClicked(int which)?, dynamic onCanceled()?}) → Future<void> -
override
-
canSecureAuthenticate(
) → Future< bool> -
inherited
-
checkAuthenticatorStatus(
MarkAuthenticatorType authenticatorType) → Future< MarkAuthenticatorStatus> -
override
-
isBiometricChanged(
{required String alias, required String encodedKey}) → Future< bool> -
override
-
isDeviceSupportBiometric(
) → Future< bool> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited