MarkPlatform class abstract
The interface that implementations of local_auth must implement.
Platform implementations should extend this class rather than implement it as local_auth
does not consider newly added methods to be breaking changes. Extending this class
(using extends) ensures that the subclass will get the default implementation, while
platform implementations that implements this interface will be broken by newly added
MarkPlatform methods.
- Inheritance
-
- Object
- PlatformInterface
- MarkPlatform
- Implementers
Constructors
- MarkPlatform()
- Constructs a MarkPlatform.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
authenticate(
{required MarkAuthenticatorType authenticatorType, required String title, String? subTitle, required String description, required String negativeText, bool confirmationRequired = false, required dynamic onSuccessAuthenticate(), dynamic onFailedAuthenticate()?, required dynamic onErrorAuthenticate(String code, String? message), dynamic onNegativeButtonClicked(int which)?, dynamic onCanceled()?}) → Future< void> -
authenticateSecureDecrypt(
{required String alias, required String encodedKey, required Map< String, String> requestForDecrypt, required String title, String? subTitle, required String description, required String negativeText, bool confirmationRequired = false, required dynamic onSuccessAuthenticate(SuccessAuthenticateDecryptState state), dynamic onFailedAuthenticate()?, required dynamic onErrorAuthenticate(String code, String? message), dynamic onNegativeButtonClicked(int which)?, dynamic onCanceled()?}) → Future<void> -
authenticateSecureEncrypt(
{required String alias, required Map< String, String> requestForEncrypt, required String title, String? subTitle, required String description, required String negativeText, bool confirmationRequired = false, required dynamic onSuccessAuthenticate(SuccessAuthenticateEncryptState state), dynamic onFailedAuthenticate()?, required dynamic onErrorAuthenticate(String code, String? message), dynamic onNegativeButtonClicked(int which)?, dynamic onCanceled()?}) → Future<void> -
canSecureAuthenticate(
) → Future< bool> -
checkAuthenticatorStatus(
MarkAuthenticatorType authenticatorType) → Future< MarkAuthenticatorStatus> -
isBiometricChanged(
{required String alias, required String encodedKey}) → Future< bool> -
isDeviceSupportBiometric(
) → Future< bool> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ MarkPlatform
-
The default instance of MarkPlatform to use.
getter/setter pair